PrintlyHriPosition enum
Placement of the Human-Readable Interpretation (HRI) digits printed
alongside a barcode (GS H).
Values
- none → const PrintlyHriPosition
-
Do not print the HRI text (
GS H 0). - above → const PrintlyHriPosition
-
Print the HRI text above the barcode (
GS H 1). - below → const PrintlyHriPosition
-
Print the HRI text below the barcode (
GS H 2). - both → const PrintlyHriPosition
-
Print the HRI text both above and below (
GS H 3).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PrintlyHriPosition> - A constant List of the values in this enum, in order of their declaration.