PrintlyTextStyle enum
Emphasis applied to a printed line.
Prefixed to avoid a name clash with dart:ui/Material's TextStyle.
Values
- normal → const PrintlyTextStyle
-
No emphasis (printer default).
- bold → const PrintlyTextStyle
-
Bold / emphasised text (
ESC E 1). - underline → const PrintlyTextStyle
-
Underlined text (
ESC - 1). - boldUnderline → const PrintlyTextStyle
-
Both bold and underlined.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isBold → bool
-
Whether this style enables bold emphasis.
no setter
- isUnderline → bool
-
Whether this style enables underline.
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PrintlyTextStyle> - A constant List of the values in this enum, in order of their declaration.